Learn R Programming

BMRMM (version 1.0.0)

diag.BMRMM: MCMC Diagnostic Plots for Transition Probabilities and Duration Times

Description

Provides the traceplots and autocorrelation plots for (i) transition probabilities and (ii) mixture gamma shape and rate parameters.

Usage

diag.BMRMM(object, cov.combs = NULL, transitions = NULL, components = NULL)

Value

None

Arguments

object

an object of class BMRMM

cov.combs

a list of covariate level combinations. Default is NULL, which is all possible combination of covariate levels.

transitions

a list of pairs denoting state transitions. Default is NULL, which is all possible state transitions.

components

a numeric vector denoting the mixture components of interest. Default is NULL, which is a list of all mixture components.

Examples

Run this code

results <- BMRMM(foxp2sm, num.cov = 2, simsize = 80, 
                 duration.distr = list('mixgamma',shape=rep(1,3),rate=rep(1,3)))
diag.BMRMM(results)
diag.BMRMM(results, cov.combs = list(c(1,1),c(1,2)), 
           transitions = list(c(1,1)), components = c(3))

Run the code above in your browser using DataLab